@@ -1,6 +1,7 @@
 """Configuration for FraiseQL FastAPI integration."""
 
 import logging
+from enum import Enum
 from typing import Annotated, Any, Literal
 
 from pydantic import Field, PostgresDsn, field_validator
@@ -9,6 +10,29 @@ from pydantic_settings import BaseSettings, SettingsConfigDict
 logger = logging.getLogger(__name__)
 
 
+class IntrospectionPolicy(str, Enum):
+    """Policy for GraphQL schema introspection access control.
+
+    - DISABLED: No introspection allowed for anyone
+    - PUBLIC: Introspection allowed for everyone (default)
+    - AUTHENTICATED: Introspection only allowed for authenticated users
+    """
+
+    DISABLED = "disabled"
+    PUBLIC = "public"
+    AUTHENTICATED = "authenticated"
+
+    def allows_introspection(self, is_authenticated: bool = False) -> bool:
+        """Check if introspection is allowed based on policy and authentication status."""
+        if self == IntrospectionPolicy.DISABLED:
+            return False
+        if self == IntrospectionPolicy.PUBLIC:
+            return True
+        if self == IntrospectionPolicy.AUTHENTICATED:
+            return is_authenticated
+        return False
+
+
 def validate_postgres_url(v: Any) -> str:
     """Validate PostgreSQL URL, supporting both regular and Unix socket connections.
 
@@ -72,7 +96,7 @@ class FraiseQLConfig(BaseSettings):
         app_name: Application name displayed in API documentation.
         app_version: Application version string.
         environment: Current environment (development/production/testing).
-        enable_introspection: Allow GraphQL schema introspection queries.
+        introspection_policy: Policy for GraphQL schema introspection access control.
         enable_playground: Enable GraphQL playground IDE.
         playground_tool: Which GraphQL IDE to use (graphiql or apollo-sandbox).
         max_query_depth: Maximum allowed query depth to prevent abuse.
@@ -106,6 +130,10 @@ class FraiseQLConfig(BaseSettings):
         camelforge_enabled: Enable CamelForge database-native camelCase transformation.
         camelforge_function: Name of the CamelForge function to use (default: turbo.fn_camelforge).
         camelforge_entity_mapping: Auto-derive entity type from GraphQL type names.
+        apq_storage_backend: Storage backend for APQ (memory/postgresql/redis/custom).
+        apq_cache_responses: Enable JSON response caching for APQ queries.
+        apq_response_cache_ttl: Cache TTL for APQ responses in seconds.
+        apq_backend_config: Backend-specific configuration options.
 
     Example:
         ```python
@@ -137,7 +165,7 @@ class FraiseQLConfig(BaseSettings):
     environment: Literal["development", "production", "testing"] = "development"
 
     # GraphQL settings
-    enable_introspection: bool = True
+    introspection_policy: IntrospectionPolicy = IntrospectionPolicy.PUBLIC
     enable_playground: bool = True
     playground_tool: Literal["graphiql", "apollo-sandbox"] = "graphiql"  # Which GraphQL IDE to use
     max_query_depth: int | None = None
@@ -221,6 +249,12 @@ class FraiseQLConfig(BaseSettings):
     rate_limit_whitelist: list[str] = []
     rate_limit_blacklist: list[str] = []
 
+    # APQ Backend Configuration
+    apq_storage_backend: Literal["memory", "postgresql", "redis", "custom"] = "memory"
+    apq_cache_responses: bool = False
+    apq_response_cache_ttl: int = Field(default=600, ge=0)
+    apq_backend_config: dict[str, Any] = {}
+
     # CORS settings
     cors_enabled: bool = False  # Disabled by default to avoid conflicts with reverse proxies
     cors_origins: list[str] = []  # Empty by default, must be explicitly configured
@@ -257,12 +291,43 @@ class FraiseQLConfig(BaseSettings):
     default_mutation_schema: str = "public"  # Default schema for mutations when not specified
     default_query_schema: str = "public"  # Default schema for queries when not specified
 
-    @field_validator("enable_introspection")
+    # Entity routing settings
+    entity_routing: Any = None
+    """Configuration for entity-aware query routing (optional)."""
+
+    @field_validator("entity_routing", mode="before")
     @classmethod
-    def introspection_for_dev_only(cls, v: bool, info) -> bool:
-        """Disable introspection in production unless explicitly enabled."""
-        if info.data.get("environment") == "production" and v is True:
-            return False
+    def validate_entity_routing(cls, v: Any) -> Any:
+        """Validate entity routing configuration."""
+        if v is None:
+            return None
+
+        from fraiseql.routing.config import EntityRoutingConfig
+
+        if isinstance(v, dict):
+            return EntityRoutingConfig(**v)
+        if isinstance(v, EntityRoutingConfig):
+            return v
+        raise ValueError("entity_routing must be an EntityRoutingConfig instance or dict")
+
+    @property
+    def enable_introspection(self) -> bool:
+        """Backward compatibility property for enable_introspection.
+
+        Returns True if introspection_policy allows any introspection.
+        For authenticated-only policies, this returns True to allow
+        the GraphQL execution layer to handle auth checks.
+        """
+        return self.introspection_policy != IntrospectionPolicy.DISABLED
+
+    @field_validator("introspection_policy")
+    @classmethod
+    def set_production_introspection_default(
+        cls, v: IntrospectionPolicy, info
+    ) -> IntrospectionPolicy:
+        """Set introspection policy to DISABLED in production unless explicitly set."""
+        if info.data.get("environment") == "production" and v == IntrospectionPolicy.PUBLIC:
+            return IntrospectionPolicy.DISABLED
         return v
 
     @field_validator("enable_playground")
